@@ -3,11 +3,14 @@ require 'spec_helper'
 describe 'nova::api' do
 
   let :pre_condition do
-    'include nova'
+    "include nova
+     class { '::nova::keystone::authtoken':
+       password => 'passw0rd',
+     }"
   end
 
   let :params do
-    { :admin_password => 'passw0rd' }
+    {}
   end
 
   shared_examples 'nova-api' do
@@ -35,19 +38,6 @@ describe 'nova::api' do
         is_expected.to_not contain_exec('validate_nova_api')
       end
 
-      it 'configures keystone_authtoken middleware' do
-       is_expected.to contain_nova_config(
-          'keystone_authtoken/auth_uri').with_value('http://127.0.0.1:5000/')
-       is_expected.to contain_nova_config(
-          'keystone_authtoken/auth_url').with_value('http://127.0.0.1:35357/')
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/project_name').with_value('services')
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/username').with_value('nova')
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/password').with_value('passw0rd').with_secret(true)
-      end
-
       it 'enable metadata in evenlet configuration' do
         is_expected.to contain_nova_config('DEFAULT/enabled_apis').with_value('osapi_compute,metadata')
       end
@@ -81,7 +71,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/enable_instance_password').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => false)
-        is_expected.to contain_nova_config('DEFAULT/pci_alias').with(:value => '<SERVICE DEFAULT>')
       end
 
       it 'unconfigures neutron_metadata proxy' do
@@ -95,16 +84,10 @@ describe 'nova::api' do
         params.merge!({
           :enabled                              => false,
           :ensure_package                       => '2012.1-2',
-          :auth_uri                             => 'https://10.0.0.1:9999/',
-          :identity_uri                         => 'https://10.0.0.1:8888/',
-          :admin_tenant_name                    => 'service2',
-          :admin_user                           => 'nova2',
-          :admin_password                       => 'passw0rd2',
           :api_bind_address                     => '192.168.56.210',
           :metadata_listen                      => '127.0.0.1',
           :metadata_listen_port                 => 8875,
           :osapi_compute_listen_port            => 8874,
-          :volume_api_class                     => 'nova.volume.cinder.API',
           :use_forwarded_for                    => false,
           :ratelimits                           => '(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)',
           :neutron_metadata_proxy_shared_secret => 'secrete',
@@ -126,6 +109,7 @@ describe 'nova::api' do
           :enable_network_quota                 => false,
           :enable_instance_password             => true,
           :password_length                      => 12,
+          :pci_alias                            => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]",
           :allow_resize_to_same_host            => true,
         })
       end
@@ -145,21 +129,6 @@ describe 'nova::api' do
         )
       end
 
-      it 'configures keystone_authtoken middleware' do
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/auth_uri').with_value('https://10.0.0.1:9999/')
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/auth_url').with_value('https://10.0.0.1:8888/')
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/project_name').with_value('service2')
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/username').with_value('nova2')
-        is_expected.to contain_nova_config(
-          'keystone_authtoken/password').with_value('passw0rd2').with_secret(true)
-        is_expected.to contain_nova_paste_api_ini(
-          'filter:ratelimit/limits').with_value('(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)')
-      end
-
       it 'configures various stuff' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with('value' => '192.168.56.210')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8874')
@@ -189,56 +158,14 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '12')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => true)
       end
-    end
 
-    context 'with pci_alias array' do
-      before do
-        params.merge!({
-          :pci_alias => [{
-              "vendor_id"  => "8086",
-              "product_id" => "0126",
-              "name"       => "graphic_card"
-            },
-            {
-              "vendor_id"  => "9096",
-              "product_id" => "1520",
-              "name"       => "network_card"
-            }
-          ]
-        })
-      end
       it 'configures nova pci_alias entries' do
         is_expected.to contain_nova_config('DEFAULT/pci_alias').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126","name":"graphic_card"}','{"vendor_id":"9096","product_id":"1520","name":"network_card"}']
+          'value' => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]"
         )
       end
     end
 
-    context 'with pci_alias JSON encoded string (deprecated)' do
-      before do
-        params.merge!({
-          :pci_alias => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]",
-        })
-      end
-      it 'configures nova pci_alias entries' do
-        is_expected.to contain_nova_config('DEFAULT/pci_alias').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126","name":"graphic_card"}','{"vendor_id":"9096","product_id":"1520","name":"network_card"}']
-        )
-      end
-    end
-
-    context 'when pci_alias is empty' do
-      before do
-        params.merge!({
-          :pci_alias => ""
-        })
-      end
-
-      it 'clears pci_alias configuration' do
-        is_expected.to contain_nova_config('DEFAULT/pci_alias').with(:value => '<SERVICE DEFAULT>')
-      end
-    end
-
     context 'while validating the service with default command' do
       before do
         params.merge!({
@@ -246,11 +173,11 @@ describe 'nova::api' do
         })
       end
       it { is_expected.to contain_exec('execute nova-api validation').with(
-        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider    => 'shell',
-        :tries       => '10',
-        :try_sleep   => '2',
-        :command     => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username nova --os-password passw0rd flavor-list',
+        :path      => '/usr/bin:/bin:/usr/sbin:/sbin',
+        :provider  => 'shell',
+        :tries     => '10',
+        :try_sleep => '2',
+        :command   => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username nova --os-password passw0rd flavor-list',
       )}
 
       it { is_expected.to contain_anchor('create nova-api anchor').with(
@@ -266,11 +193,11 @@ describe 'nova::api' do
         })
       end
       it { is_expected.to contain_exec('execute nova-api validation').with(
-        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider    => 'shell',
-        :tries       => '10',
-        :try_sleep   => '2',
-        :command     => 'my-script',
+        :path      => '/usr/bin:/bin:/usr/sbin:/sbin',
+        :provider  => 'shell',
+        :tries     => '10',
+        :try_sleep => '2',
+        :command   => 'my-script',
       )}
 
       it { is_expected.to contain_anchor('create nova-api anchor').with(
@@ -281,8 +208,8 @@ describe 'nova::api' do
     context 'while not managing service state' do
       before do
         params.merge!({
-          :enabled           => false,
-          :manage_service    => false,
+          :enabled        => false,
+          :manage_service => false,
         })
       end
 
@@ -291,7 +218,10 @@ describe 'nova::api' do
 
     context 'with default database parameters' do
       let :pre_condition do
-        "include nova"
+        "include nova
+         class { '::nova::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
       end
 
       it { is_expected.to_not contain_nova_config('database/connection') }
@@ -310,6 +240,9 @@ describe 'nova::api' do
            api_slave_connection    => 'mysql://user:pass@slave/db2',
            database_idle_timeout   => '30',
          }
+         class { '::nova::keystone::authtoken':
+           password => 'passw0rd',
+         }
         "
       end
 
@@ -338,15 +271,18 @@ describe 'nova::api' do
 
       let :pre_condition do
         "include ::apache
-         include ::nova"
+         include ::nova
+         class { '::nova::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
       end
 
       it 'enable nova API service' do
         is_expected.to contain_service('nova-api').with(
-          :ensure     => 'running',
-          :name       => platform_params[:nova_api_service],
-          :enable     => true,
-          :tag        => 'nova-service',
+          :ensure => 'running',
+          :name   => platform_params[:nova_api_service],
+          :enable => true,
+          :tag    => 'nova-service',
         )
       end
       it 'enable metadata in evenlet configuration' do
@@ -363,15 +299,18 @@ describe 'nova::api' do
 
       let :pre_condition do
         "include ::apache
-         include ::nova"
+         include ::nova
+         class { '::nova::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
       end
 
       it 'disable nova API service' do
         is_expected.to contain_service('nova-api').with(
-          :ensure     => 'stopped',
-          :name       => platform_params[:nova_api_service],
-          :enable     => false,
-          :tag        => 'nova-service',
+          :ensure => 'stopped',
+          :name   => platform_params[:nova_api_service],
+          :enable => false,
+          :tag    => 'nova-service',
         )
       end
     end
@@ -392,7 +331,10 @@ describe 'nova::api' do
 
       let :pre_condition do
         "include ::apache
-         include ::nova"
+         include ::nova
+         class { '::nova::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
       end
 
       it_raises 'a Puppet::Error', /Invalid service_name/
