@@ -58,11 +58,14 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
-        is_expected.to contain_nova_config('DEFAULT/use_ipv6').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/catalog_info').with('value' => 'volumev2:cinderv2:publicURL')
+        is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -91,7 +94,6 @@ describe 'nova' do
           :service_down_time                       => '120',
           :auth_strategy                           => 'foo',
           :ensure_package                          => '2012.1.1-15.el6',
-          :memcached_servers                       => ['memcached01:11211', 'memcached02:11211'],
           :host                                    => 'test-001.example.org',
           :notification_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                     => 'ceilometer.compute.nova_notifier',
@@ -148,10 +150,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
       end
 
-      it 'configures memcached_servers' do
-        is_expected.to contain_nova_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
-      end
-
       it 'configures host' do
         is_expected.to contain_nova_config('DEFAULT/host').with_value('test-001.example.org')
       end
@@ -178,7 +176,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('DEFAULT/notify_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
-        is_expected.to contain_nova_config('DEFAULT/use_ipv6').with_value('true')
+        is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('true')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
       end
 
@@ -562,11 +560,25 @@ describe 'nova' do
       it { is_expected.to contain_nova_config('ssl/key_file').with_ensure('absent') }
     end
 
+    context 'with allocation ratios set' do
+      let :params do
+        {
+          :cpu_allocation_ratio  => 32.0,
+          :ram_allocation_ratio  => 2.0,
+          :disk_allocation_ratio => 1.5,
+        }
+      end
+
+      it { is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('32.0') }
+      it { is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('2.0') }
+      it { is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('1.5') }
+    end
+
   end
 
 
   on_supported_os({
-    :supported_oos => OSDefaults.get_supported_os
+    :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
